[Python-checkins] python/dist/src/Lib/test test_doctest.py, 1.33, 1.34

edloper at users.sourceforge.net edloper at users.sourceforge.net
Thu Aug 26 03:41:53 CEST 2004


Update of /cvsroot/python/python/dist/src/Lib/test
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv19362/dist/src/Lib/test

Modified Files:
	test_doctest.py 
Log Message:
Renamed UNIFIED_DIFF->REPORT_UDIFF; CONTEXT_DIFF->REPORT_CDIFF; and
NDIFF_DIFF->REPORT_NDIFF.  This establishes the naming convention that
all reporting options should begin with "REPORT_" (since reporting
options are a different class from output comparison options; but they
are both set in optionflags).


Index: test_doctest.py
===================================================================
RCS file: /cvsroot/python/python/dist/src/Lib/test/test_doctest.py,v
retrieving revision 1.33
retrieving revision 1.34
diff -u -d -r1.33 -r1.34
--- test_doctest.py	26 Aug 2004 01:31:56 -0000	1.33
+++ test_doctest.py	26 Aug 2004 01:41:51 -0000	1.34
@@ -923,7 +923,7 @@
     ...                 # doctest: +NORMALIZE_WHITESPACE
     [0,    1, ...,   18,    19]
 
-The UNIFIED_DIFF flag causes failures that involve multi-line expected
+The REPORT_UDIFF flag causes failures that involve multi-line expected
 and actual outputs to be displayed using a unified diff:
 
     >>> def f(x):
@@ -965,7 +965,7 @@
 
     >>> # With the flag:
     >>> test = doctest.DocTestFinder().find(f)[0]
-    >>> flags = doctest.UNIFIED_DIFF
+    >>> flags = doctest.REPORT_UDIFF
     >>> doctest.DocTestRunner(verbose=False, optionflags=flags).run(test)
     **********************************************************************
     Line 2, in f
@@ -985,12 +985,12 @@
     <BLANKLINE>
     (1, 1)
 
-The CONTEXT_DIFF flag causes failures that involve multi-line expected
+The REPORT_CDIFF flag causes failures that involve multi-line expected
 and actual outputs to be displayed using a context diff:
 
-    >>> # Reuse f() from the UNIFIED_DIFF example, above.
+    >>> # Reuse f() from the REPORT_UDIFF example, above.
     >>> test = doctest.DocTestFinder().find(f)[0]
-    >>> flags = doctest.CONTEXT_DIFF
+    >>> flags = doctest.REPORT_CDIFF
     >>> doctest.DocTestRunner(verbose=False, optionflags=flags).run(test)
     **********************************************************************
     Line 2, in f
@@ -1019,7 +1019,7 @@
     (1, 1)
 
 
-The NDIFF_DIFF flag causes failures to use the difflib.Differ algorithm
+The REPORT_NDIFF flag causes failures to use the difflib.Differ algorithm
 used by the popular ndiff.py utility.  This does intraline difference
 marking, as well as interline differences.
 
@@ -1029,7 +1029,7 @@
     ...     a b c d e f g h i j k 1 m
     ...     '''
     >>> test = doctest.DocTestFinder().find(f)[0]
-    >>> flags = doctest.NDIFF_DIFF
+    >>> flags = doctest.REPORT_NDIFF
     >>> doctest.DocTestRunner(verbose=False, optionflags=flags).run(test)
     **********************************************************************
     Line 2, in f



More information about the Python-checkins mailing list